datastructuretools.ObjectInventory
==================================

.. inheritance-diagram:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory
   :private-bases:

.. autoclass:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.inventory_name

Methods
-------

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.append

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.count

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.extend

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.index

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.insert

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.pop

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.remove

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.reverse

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.sort

   .. note:: Inherited from `__builtin__.list`

Special Methods
---------------

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__add__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__contains__

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__delitem__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__delslice__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__eq__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__ge__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__getitem__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__getslice__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__gt__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__iadd__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__imul__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__iter__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__le__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__len__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__lt__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__mul__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__ne__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__repr__

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__reversed__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__rmul__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__setitem__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__setslice__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__str__

   .. note:: Inherited from `__builtin__.object`
